CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Recommended modules
 * Installation
 * Configuration
 * Troubleshooting
 * Maintainers

INTRODUCTION
------------
 
 Provides Layout plugins that feature a background region. The background
 region can accept any number of blocks. The first block that is not empty
 will be rendered and the magic of object-fit is used to make the image
 (assuming the block contains an image!) behave like a background image.
 This "use the first non-empty block" technique allows for cool
 fallback strategies and easy management of default backgrounds. 
 
 Since it's not really a background image and is instead an actual img
 tag, there's a ridiculous amount of flexibility! Most likely, you will
 be adding a field block to the background region, where the field is an
 image field or a media reference field. You can use any field formatter
 that renders the field as an img tag. It works with just about anything!
   1. Image ans Media Thumbnails
   2. Image styles
   3. Responsive Images
   4. Blazy (lazy loading)
   5. Images in a WYSIWYG

 And none of it takes any more configuration than you are used to! It's
 all thanks to the magic of object-fit.

 Just to clarify, you do not need to (nor should you) use any special field 
 formatters that are typically used for background images. This module gives
 the illusion of background images while still using real img tags. That's
 why it's so easily compatible with Blazy and Responsive Images.
 
 * For a full description of the module, visit the project page:
   https://drupal.org/project/layout_bg

 * To submit bug reports and feature suggestions, or to track changes:
   https://drupal.org/project/issues/layout_bg
   
MAKE YOUR OWN LAYOUTS WITH BG
-----------------------------

In addition to shipping with two layouts that add a background region to core
layouts this module can be used to create new custom layouts that have
a background region. Here are the basic steps:
  1. Pick a Layout plugin to extend. Create a new class that extends that
     layout by using the LayoutBgTrait. Also set the baseLayoutTemplate
     variable. See the LayoutBgOneCol.php class as the simplest example of 
     this technique.
  2. Create a library that you new layout will use. It should have two
     dependencies: layout_bg/layout_bg and then the library used by the
     layout you are extending. See layout_bg.libraries.yml for examples.
  3. When registering your new layout in your module/theme .layouts.yml, use
     layout--layout-bg as your template and use your new library as the 
     library. See layout_bg.layouts.yml as an example.

If you don't like the baseLayoutTemplate system, you could opt not to use
layout--layout-bg as your template and just make your own.

REQUIREMENTS
------------

 * Layout Builder and Layout Discovery (both in core) are required.

RECOMMENDED MODULES
-------------------

 * This module works great with Responsive Image and lazy loading modules
   like Blazy.

INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.

CONFIGURATION
-------------

 * There is no global configuration for this module.
 * Any Layout Section provided by this module has several configuration options.
   Specifically, you may configure a background color, overlay color, 
   overlay opacity, and text color. There is also a configuration option that 
   controls the behavior of the background image.

TROUBLESHOOTING
---------------

 * Q: Does your browser support object-fit?
   A: If not, this won't work.
 
 * Q: Is there more than a single img tag being rendered in the background?
   A: If so, that may mess things up. Avoid text in the background region.
      Block labels get suppressed by default for this reason.


MAINTAINERS
-----------

Current maintainers:

 * danflanagan8
